'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

/**
 * Field
 * A reuseable field element
 */

function objectWithoutProperties (obj, exclude) { var target = {}; for (var k in obj) if (Object.prototype.hasOwnProperty.call(obj, k) && exclude.indexOf(k) === -1) target[k] = obj[k]; return target; }

function uid(len) {
  len = len || 7;
  return Math.random()
    .toString(35)
    .substr(2, len)
}

var defaultProps = {
  hint: null,
  element: 'input',
  type: 'text'
};

var Field = (function (superclass) {
  function Field() {
    superclass.apply(this, arguments);

    this.state = {
      hintId: ("hint-col-field-" + (uid()))
    };
  }

  if ( superclass ) Field.__proto__ = superclass;
  Field.prototype = Object.create( superclass && superclass.prototype );
  Field.prototype.constructor = Field;

  Field.prototype.getHint = function getHint (hint) {
    return hint ? (
      React.createElement( 'span', { id: this.state.hintId, className: "col-field-hint" },
        hint
      )
    ) : null
  };

  Field.prototype.render = function render () {
    var this$1 = this;

    var ref = this.props;
    var hint = ref.hint;
    var Element = ref.element;
    var label = ref.label;
    var rest = objectWithoutProperties( ref, ["hint", "element", "label"] );
    var props = rest;
    var ref$1 = this.state;
    var hintId = ref$1.hintId;

    return (
      React.createElement( 'label', { className: "col-field" },
        React.createElement( 'span', { className: "col-field-label" }, label),

        React.createElement( Element, true({},
          { ref: function (el) { return (this$1.input = el); }, className: "col-field-input", 'aria-describedby': hint ? hintId : null }, props)),
        this.getHint(hint)
      )
    )
  };

  return Field;
}(React.Component));

Field.defaultProps = defaultProps;

var toArray = function (list) { return Array.prototype.slice.call(list); };

function sanitize(html) {
  var bucket = document.createElement('div');

  bucket.innerHTML = html;

  var doNotAllow = toArray(bucket.querySelectorAll('script, style'));

  doNotAllow.forEach(function (el) { return el.parentNode.removeChild(el); });

  return bucket.innerHTML
}

/**
 * HTML Embed
 * A reuseable element for embedding HTML and associated JS.
 */

var defaultProps$1 = {
  content: {
    html: '',
    script: ''
  }
};

var HtmlEmbedBlock = (function (superclass) {
  function HtmlEmbedBlock () {
    superclass.apply(this, arguments);
  }

  if ( superclass ) HtmlEmbedBlock.__proto__ = superclass;
  HtmlEmbedBlock.prototype = Object.create( superclass && superclass.prototype );
  HtmlEmbedBlock.prototype.constructor = HtmlEmbedBlock;

  HtmlEmbedBlock.prototype.shouldDisplaySandbox = function shouldDisplaySandbox () {
    return this.props.content.html || this.props.content.script
  };

  HtmlEmbedBlock.prototype.getSandbox = function getSandbox () {
    var ref = this.props.content;
    var html = ref.html; if ( html === void 0 ) html = '';
    var script = ref.script; if ( script === void 0 ) script = '';

    var encoding = 'data:text/html;charset=utf-8,';
    var style = '<style>body { margin: 0 }</style>';
    var javascript = "<script src=\"" + script + "\" async></script>";
    var embeddable = encoding + escape(style + html + javascript);

    return React.createElement( 'iframe', { className: "col-block-html-frame", src: embeddable })
  };

  HtmlEmbedBlock.prototype.render = function render () {
    var this$1 = this;

    var ref = this.props.content;
    var html = ref.html;
    var script = ref.script;

    return (
      React.createElement( 'div', null,
        React.createElement( Field, {
          className: "col-block-html", label: "HTML Embed", element: "textarea", hint: "Paste HTML into this field. Include related JavaScript below.", ref: function (el) { return (this$1.html = el); }, value: html, onChange: this.onHTMLChange.bind(this) }),

        React.createElement( Field, {
          label: "Embedded JavaScript URL", hint: "Paste the JavaScript URL of the embed into this field.", ref: function (el) { return (this$1.script = el); }, value: script, onChange: this.onScriptChange.bind(this) }),

        this.shouldDisplaySandbox() ? this.getSandbox() : null
      )
    )
  };

  HtmlEmbedBlock.prototype.onScriptChange = function onScriptChange (event) {
    this.props.onChange({ script: event.target.value });
  };

  HtmlEmbedBlock.prototype.onHTMLChange = function onHTMLChange (event) {
    this.props.onChange({ html: sanitize(event.target.value) });
  };

  return HtmlEmbedBlock;
}(React.Component));

HtmlEmbedBlock.defaultProps = defaultProps$1;

module.exports = HtmlEmbedBlock;
//# sourceMappingURL=html-embed.js.map
